import os
import requests

# 文件操作
# from .fs import delete
# from .fs import read
# from .fs import write
# from .fs import write
# from .fs import cwd


from .fs import *

# 数据转化
from .to import num

# 操作系统指令
from .cmd import run


def test():
    print("test            :", 15160)



import shutil, os, pathlib


def read(my_file_path):
    my_error = ""
    # 判断绝对路径
    # if not os.path.isabs(my_file_path):
    #     my_error = my_error + f"1请检查路径是不是绝对路径|      {my_file_path}"

    # 判断存在文件吗
    if not os.path.exists(my_file_path):
        my_error = my_error + f"2请检查路径是否存在      |       {my_file_path}"

    if not my_error == "":
        print("fs.read            my_error:", my_error)

    # ========================================================================

    with open(my_file_path, 'r', encoding='utf-8') as f:
        return f.read()


#
# def read(my_path):
#     # if not self.is_error():
#     #     return self.my_error
#
#
#     with open(my_path, 'r', encoding='utf-8') as f:
#         return f.read()


if __name__ == '__main__':
    res1 = read(r"E:\AAA\xxx\ast_chrome\a08_驱动测试_cookie_打包_发布\astmain_py222\astmain\fs\aaa.txt")
    print("res1            :", res1)

    res2 = read(r"E:\AAA\xxx\ast_chrome\a08_驱动测试_cookie_打包_发布\astmain_py222\astmain\fs\maker_config.json")
    print("res2            :", res2)



class calc:
    val="ccc"
    def __init__(self):
        self._val=0
    def __add__(self,other):
        print(  111111111111111111111 , other  )
        if isinstance (other,str):
            self._val=  self._val+ int( other)
            return    self._val
        else:
            self._val=   self._val+ other
            return    self._val

    def __getitem__(self,item):
        print(222, item )
        return self

    @property
    def a(self):
        return self


    @property
    def b(self):
        return self

    def __call__(self,*args,**kwargs):
        return self

    def __getattr__(self,item):
        if item in ["a","b","c","d","f","g"]:
            print(item)
            return self


    def __truediv__(self,item):
        return self
    
    def __floordiv__(self,item):
        return self




c=calc()
print(      c+111+222   )
# print(      c+111+"222"   )
c[""][9999][:][...][:,:]

c.a.b
c.a.b.c.a.c.b.f.g()

https=www=com=index=baodu=html=calc()
https//www

# ====================================================


def f(*arg):
    print(arg)
    if arg == "":
        ...
    return f

f("唱歌")("跳舞")


class calc:
    val="ccc"
    def __init__(self):
        self._val=0
    def __add__(self,other):
        print(  111111111111111111111 , other  )
        if isinstance (other,str):
            self._val=  self._val+ int( other)
            return    self._val
        else:
            self._val=   self._val+ other
            return    self._val

    def __getitem__(self,item):
        print(222, item )
        return self

    @property
    def a(self):
        return self


    @property
    def b(self):
        return self

    def __call__(self,*args,**kwargs):
        return self

    def __getattr__(self,item):
        return self


    def __truediv__(self,item):
        return self
    
    def __floordiv__(self,item):
        return self


# https://www.bilibili.com/video/BV1x1421C7bM/

# https=www=com=index=baodu=html=calc()
https=www=index=calc()
https//www.baodu.com/index.html



import datetime

from write_add import write_add



def log(info):
    time1 = "error|||"+datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + "|||"
    content =  "error|||"+datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + "|||" + info
    write_add(r"C:\Users\Administrator\Desktop\log.txt", content)



if __name__ == '__main__':
    log("11111111111111")



import asyncio
import datetime
import inspect
import functools
import traceback

from ..fs.write_add import write_add
def try_error(level):
    def decorator(func):
        is_await = inspect.iscoroutinefunction(func)
        # print("is_await                 :", is_await)

        # 普通函数========================
        if is_await == False:
            # print("普通函数                 :", func.__name__)
            def wrapper(*args, **kwargs):
                try:
                    return func(*args, **kwargs)
                except Exception as error:
                    content = "error|||" + datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + "|||" + str(error)
                    write_add(r"C:\Users\Administrator\Desktop\log.txt", content)
                    print("\033[31m", "失败            :", content, "\033[0m")

            return wrapper

        # 异步函数========================
        if is_await == True:
            # print("异步函数                 :", func.__name__)
            @functools.wraps(func)
            async def wrapper(*args, **kwargs):
                try:
                    return await func(*args, **kwargs)
                except Exception as error:
                    content = "error|||" + datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S") + "|||" + str(traceback.format_exc())
                    write_add(r"C:\Users\Administrator\Desktop\log.txt", content)
                    print("\033[31m", "失败            :", content, "\033[0m")

            return wrapper

    return decorator


if __name__ == '__main__':
    # @log("debug")
    # def do_something():
    #     print("Doing something...")

    # do_something()

    @try_error("debug")
    async def do_something222():
        await asyncio.sleep(1)
        1 / 0
        print("111111111                 :", 111)


    asyncio.run(do_something222())



import shutil, os, pathlib, json


def write_add(my_path, xxx):
    if isinstance(xxx, dict) or isinstance(xxx, list):
        # print("write_add.字典和数组")
        with open(my_path, 'a+', encoding="utf-8") as f:
            json_str = json.dumps(xxx, ensure_ascii=False, indent=4)
            f.write(json_str + "\n")
            # print("write_add.存储完成", my_path)
            return True



    elif isinstance(xxx, str):
        # print("write_add.字符")
        with open(my_path, 'a+', encoding="utf-8") as f:
            f.write(xxx + "\n")
            # print("write_add.存储完成", my_path)
            return True
    else:
        # print("write_add.其它类型")
        return False


if __name__ == '__main__':
    res1 = write_add(r"./dist1111.txt", "222")
    print("res1            :", res1)
